
/* eslint strict: 0 */
require.config({
    // Karma serves files under /base, which is the basePath from your config file
    baseUrl: '/base/apps',

    // dynamically load all test files
    deps: Object.keys(window.__karma__.files).filter(function (file) {
        return (/\/(tk|settings)\/.*_spec\.js$/i).test(file);
    }),

    // global helper code for the tests to be loaded with RequireJS
    paths: {
        globals: '/base/spec/globals'
    },

    // we have to kickoff jasmine, as it is asynchronous
    callback: window.__karma__.start
});
